"use client";
import React, { useState, useEffect } from "react";
import { Text, Button, TextInput, PasswordInput, Title, Card, Box, Image } from "@mantine/core";
import { notifications } from "@mantine/notifications";
import { Providers } from "@/app/providers";
import { useRouter } from "next/navigation";
import NextImage from "next/image";
import myImage from '@/app/image/ebanking.jpg';
import changePwdImage from '@/app/image/changepw.png';
import CaptchaImage from './CaptchaImage';

export default function ChangeTransactionPwd() {
    const router = useRouter();
    const [authorized, SetAuthorized] = useState<boolean | null>(null);
    const [password, setPassword] = useState("");
    const [confirmPassword, setConfirmPassword] = useState("");
    const [captcha, setCaptcha] = useState("");
    const [captchaInput, setCaptchaInput] = useState('');
    const [captchaError, setCaptchaError] = useState('');

    useEffect(() => {
        generateCaptcha();
    }, []);

    const generateCaptcha = () => {
        const chars = 'ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789';
        let result = '';
        for (let i = 0; i < 6; i++) {
            result += chars.charAt(Math.floor(Math.random() * chars.length));
        }
        setCaptcha(result);
        setCaptchaInput('');
        setCaptchaError('');
    };

    async function handleSetTransactionPassword(e: React.FormEvent) {
        e.preventDefault();
        const pwdRegex = /^(?=.*[A-Z])(?=.*\d)(?=.*[@$!%*#?&])[A-Za-z\d@$!%*#?&]{8,}$/;
        if (!password || !confirmPassword) {
            notifications.show({
                withBorder: true,
                color: "red",
                title: "Both password fields are required.",
                message: "Both password fields are required.",
                autoClose: 5000,
            });
            return;
            // alert("Both password fields are required.");
        } else if (password !== confirmPassword) {
            // alert("Passwords do not match.");
            notifications.show({
                withBorder: true,
                color: "red",
                title: "Passwords do not match.",
                message: "Passwords do not match.",
                autoClose: 5000,
            });
            return;
        }
        else if (!pwdRegex.test(password)) {
            // alert("Password must contain at least 1 capital letter, 1 number, 1 special character, and be at least 8 characters long.");
            notifications.show({
                withBorder: true,
                color: "red",
                title: "Password must contain at least 1 capital letter, 1 number, 1 special character, and be at least 8 characters long.",
                message: "Password must contain at least 1 capital letter, 1 number, 1 special character, and be at least 8 characters long.",
                autoClose: 5000,
            });
            return;
        }
        else if (captchaInput !== captcha) {
            setCaptchaError("Incorrect CAPTCHA.");
            return;
        }
        const token = localStorage.getItem("access_token");
        const response = await fetch('api/auth/transaction_password', {
            method: 'POST',
            headers: {
                'Content-Type': 'application/json',
                'Authorization': `Bearer ${token}`
            },
            body: JSON.stringify({
                transaction_password: password,
            }),
        });
        const data = await response.json();
        if (response.ok) {
            console.log(data);
            notifications.show({
                withBorder: true,
                color: "green",
                title: "Transaction Password has been set",
                message: "Transaction Password has been set",
                autoClose: 5000,
            });
            router.push("/login");
        }
        else {
            notifications.show({
                withBorder: true,
                color: "red",
                title: "Please try again later ",
                message: "Please try again later ",
                autoClose: 5000,
            });
            router.push("/login");
        }
    }

    useEffect(() => {
        const token = localStorage.getItem("access_token");
        if (!token) {
            SetAuthorized(false);
            router.push("/login");
        }
        else {
            SetAuthorized(true);
        }
    }, []);

    if (authorized) {
        return (
            <Providers>
                <div style={{ backgroundColor: "#f8f9fa", width: "100%", height: "auto", paddingTop: "5%" }}>
                    <Box style={{ position: 'fixed', width: '100%', height: '12%', top: 0, left: 0, zIndex: 100 }}>
                        <Image
                            // radius="md"
                            fit="cover"
                            src={myImage}
                            component={NextImage}
                            alt="ebanking"
                            style={{ width: "100%", height: "100%" }}
                        />
                    </Box>
                    <div style={{ marginTop: '10px' }}>
                        <Box style={{ display: "flex", justifyContent: "center", alignItems: "center", columnGap: "5rem" }} bg="#c1e0f0">
                            <Image h="85vh" fit="contain" component={NextImage} src={changePwdImage} alt="Change Password Image" />
                            <Box h="100%" style={{ display: "flex", justifyContent: "center", alignItems: "center" }}>
                                <Card p="xl" w="35vw">
                                    <Title order={3}
                                        // @ts-ignore
                                        align="center" mb="md">Set Transaction Password</Title>
                                    <form onSubmit={handleSetTransactionPassword}>
                                        <PasswordInput
                                            label="Transaction Password"
                                            placeholder="Enter your Transaction password"
                                            required
                                            id="loginPassword"
                                            value={password}
                                            onChange={(e) => setPassword(e.currentTarget.value)}
                                            onCopy={(e) => e.preventDefault()}
                                            onPaste={(e) => e.preventDefault()}
                                            onCut={(e) => e.preventDefault()}
                                        />
                                        <PasswordInput
                                            label="Confirm Transaction Password"
                                            placeholder="Re-enter your Transaction password"
                                            required
                                            id="confirmPassword"
                                            value={confirmPassword}
                                            onChange={(e) => setConfirmPassword(e.currentTarget.value)}
                                            onCopy={(e) => e.preventDefault()}
                                            onPaste={(e) => e.preventDefault()}
                                            onCut={(e) => e.preventDefault()}
                                        />
                                        {/* CAPTCHA */}
                                        <div style={{ marginTop: 20 }}>
                                            <label style={{ fontWeight: 600 }}>Enter CAPTCHA *</label>
                                            <div style={{ display: 'flex', alignItems: 'center', gap: 10, marginBottom: 5 }}>
                                                <CaptchaImage text={captcha} />
                                                <Button size="xs" variant="outline" onClick={generateCaptcha}>Refresh</Button>
                                            </div>
                                            <TextInput
                                                placeholder="Enter above text"
                                                value={captchaInput}
                                                onChange={(e) => setCaptchaInput(e.currentTarget.value)}
                                                required
                                            />
                                            {captchaError && <p style={{ color: 'red' }}>{captchaError}</p>}
                                        </div>

                                        <Button
                                            type="submit"
                                            fullWidth
                                            mt="sm"
                                            color="blue"
                                        >
                                            Set
                                        </Button>


                                    </form>

                                    <br></br>
                                    <Box
                                        style={{
                                            flex: 1,
                                            borderLeft: '1px solid #ccc',
                                            paddingLeft: 16,
                                            minHeight: 90,

                                        }}
                                    >
                                        <Text size="sm">
                                            <strong>Note:</strong> Password will contains minimum one alphabet, one digit, one special symbol and total 8 charecters.
                                        </Text>
                                    </Box>
                                </Card>
                            </Box>
                        </Box>
                        <Box
                            component="footer"
                            style={{
                                width: "100%",
                                textAlign: "center",
                                padding: "10px 0",
                                bottom: 0,
                                left: 0,
                                zIndex: 1000,
                                fontSize: "14px",
                            }}
                        >
                            <Text>
                                © 2025 KCC Bank. All rights reserved. {" "}

                            </Text>
                        </Box>
                    </div>
                </div>
            </Providers >
        );
    }
}
